<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://brewpixel.com
 * @since             1.0.0
 * @package           BrewPixel_Maps
 *
 * @wordpress-plugin
 * Plugin Name:       BrewPixel Maps
 * Plugin URI:        https://brewpixel.com/plugins/brewpixel-maps/
 * Description:       Enables live maps to be displayed using relevant APIs.
 * Version:           1.0.3
 * Author:            Martin Goldie, BrewPixel
 * Author URI:        https://brewpixel.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       brewpixel-maps
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-brewpixel-maps-activator.php
 */
function activate_brewpixel_maps() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-brewpixel-maps-activator.php';
	BrewPixel_Maps_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-brewpixel-maps-deactivator.php
 */
function deactivate_brewpixel_maps() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-brewpixel-maps-deactivator.php';
	BrewPixel_Maps_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_brewpixel_maps' );
register_deactivation_hook( __FILE__, 'deactivate_brewpixel_maps' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-brewpixel-maps.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_brewpixel_maps() {

	$plugin = new BrewPixel_Maps();
	$plugin->run();

}
run_brewpixel_maps();
