<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://brewpixel.com
 * @since      1.0.0
 *
 * @package    BrewPixel_Maps
 * @subpackage BrewPixel_Maps/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    BrewPixel_Maps
 * @subpackage BrewPixel_Maps/public
 * @author     Martin Goldie <martin@brewpixel.com>
 */
class BrewPixel_Maps_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $brewpixel_maps    The ID of this plugin.
	 */
	private $brewpixel_maps;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * The Google Maps API Key.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $apikey    The Google Maps API Key.
	 */
	private $apikey;

	/**
	 * The pages this plugin should be active on.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      array    $version    The current version of this plugin.
	 */
	private $pages;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $brewpixel_maps       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $brewpixel_maps, $version ) {

		$this->brewpixel_maps = $brewpixel_maps;
		$this->version = $version;
		$this->apikey = get_option( 'bp_google_maps_api_key' );

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in BrewPixel_Maps_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The BrewPixel_Maps_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		$this->pages = array_map('trim', explode(',', get_option( 'bp_google_maps_pages' ) ) );
		if( ! get_option( 'bp_google_maps') || ! is_page( $this->pages ) ) {
			return;
		}
		wp_enqueue_style( $this->brewpixel_maps, plugin_dir_url( __FILE__ ) . 'css/brewpixel-maps-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in BrewPixel_Maps_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The BrewPixel_Maps_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		$this->pages = array_map('trim', explode(',', get_option( 'bp_google_maps_pages' ) ) );
		if( ! get_option( 'bp_google_maps') || ! is_page( $this->pages ) ) {
			return;
		}
		wp_enqueue_script( 'google-map-api', "https://maps.googleapis.com/maps/api/js?key=$this->apikey", array(), $this->version, false );
		wp_enqueue_script( $this->brewpixel_maps, plugin_dir_url( __FILE__ ) . 'js/brewpixel-maps-public.js', array( 'google-map-api' ), $this->version, false );

	}

}
